@@ -1,6 +1,6 @@
 package NetHack::Item::Spoiler::Spellbook;
 {
-  $NetHack::Item::Spoiler::Spellbook::VERSION = '0.14';
+  $NetHack::Item::Spoiler::Spellbook::VERSION = '0.15';
 }
 use strict;
 use warnings;
@@ -45,6 +45,8 @@ sub _list {
             time      => 2,
             ink       => 10,
             emergency => 0,
+            skill     => 'attack',
+            direction => 'beam',
         },
         'spellbook of drain life' => {
             price     => 200,
@@ -52,6 +54,8 @@ sub _list {
             time      => 2,
             ink       => 20,
             emergency => 0,
+            skill     => 'attack',
+            direction => 'beam',
         },
         'spellbook of magic missile' => {
             price     => 200,
@@ -60,6 +64,8 @@ sub _list {
             ink       => 20,
             role      => 'Wiz',
             emergency => 0,
+            skill     => 'attack',
+            direction => 'ray',
         },
         'spellbook of cone of cold' => {
             price     => 400,
@@ -68,6 +74,13 @@ sub _list {
             ink       => 40,
             role      => 'Val',
             emergency => 0,
+            skill     => 'attack',
+            direction => {
+                unskilled => 'ray',
+                basic     => 'ray',
+                skilled   => 'distant',
+                expert    => 'distant',
+            },
         },
         'spellbook of fireball' => {
             price     => 400,
@@ -75,6 +88,13 @@ sub _list {
             time      => 12,
             ink       => 40,
             emergency => 0,
+            skill     => 'attack',
+            direction => {
+                unskilled => 'ray',
+                basic     => 'ray',
+                skilled   => 'distant',
+                expert    => 'distant',
+            },
         },
         'spellbook of finger of death' => {
             price     => 700,
@@ -82,6 +102,8 @@ sub _list {
             time      => 80,
             ink       => 70,
             emergency => 0,
+            skill     => 'attack',
+            direction => 'ray',
         },
         'spellbook of healing' => {
             price     => 100,
@@ -89,6 +111,8 @@ sub _list {
             time      => 2,
             ink       => 10,
             emergency => 1,
+            skill     => 'healing',
+            direction => 'beam',
         },
         'spellbook of cure blindness' => {
             price     => 200,
@@ -96,6 +120,8 @@ sub _list {
             time      => 2,
             ink       => 20,
             emergency => 1,
+            skill     => 'healing',
+            direction => 'nodir',
         },
         'spellbook of cure sickness' => {
             price     => 300,
@@ -104,6 +130,8 @@ sub _list {
             ink       => 30,
             role      => 'Hea',
             emergency => 1,
+            skill     => 'healing',
+            direction => 'nodir',
         },
         'spellbook of extra healing' => {
             price     => 300,
@@ -111,6 +139,8 @@ sub _list {
             time      => 10,
             ink       => 30,
             emergency => 1,
+            skill     => 'healing',
+            direction => 'beam',
         },
         'spellbook of stone to flesh' => {
             price     => 300,
@@ -118,6 +148,8 @@ sub _list {
             time      => 2,
             ink       => 30,
             emergency => 0,
+            skill     => 'healing',
+            direction => 'beam',
         },
         'spellbook of restore ability' => {
             price     => 400,
@@ -126,6 +158,8 @@ sub _list {
             ink       => 40,
             role      => 'Mon',
             emergency => 1,
+            skill     => 'healing',
+            direction => 'nodir',
         },
         'spellbook of detect monsters' => {
             price     => 100,
@@ -133,6 +167,8 @@ sub _list {
             time      => 1,
             ink       => 10,
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of light' => {
             price     => 100,
@@ -140,6 +176,8 @@ sub _list {
             time      => 1,
             ink       => 10,
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of detect food' => {
             price     => 200,
@@ -147,6 +185,8 @@ sub _list {
             time      => 3,
             ink       => 20,
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of clairvoyance' => {
             price     => 300,
@@ -155,6 +195,8 @@ sub _list {
             ink       => 30,
             role      => 'Sam',
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of detect unseen' => {
             price     => 300,
@@ -162,6 +204,8 @@ sub _list {
             time      => 8,
             ink       => 30,
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of identify' => {
             price     => 300,
@@ -169,6 +213,8 @@ sub _list {
             time      => 12,
             ink       => 30,
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of detect treasure' => {
             price     => 400,
@@ -177,6 +223,8 @@ sub _list {
             ink       => 40,
             role      => 'Rog',
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of magic mapping' => {
             price     => 500,
@@ -185,6 +233,8 @@ sub _list {
             ink       => 50,
             role      => 'Arc',
             emergency => 0,
+            skill     => 'divination',
+            direction => 'nodir',
         },
         'spellbook of sleep' => {
             price     => 100,
@@ -192,6 +242,8 @@ sub _list {
             time      => 1,
             ink       => 10,
             emergency => 0,
+            skill     => 'enchantment',
+            direction => 'ray',
         },
         'spellbook of confuse monster' => {
             price     => 200,
@@ -199,6 +251,8 @@ sub _list {
             time      => 2,
             ink       => 20,
             emergency => 0,
+            skill     => 'enchantment',
+            direction => 'nodir',
         },
         'spellbook of slow monster' => {
             price     => 200,
@@ -206,6 +260,8 @@ sub _list {
             time      => 2,
             ink       => 20,
             emergency => 0,
+            skill     => 'enchantment',
+            direction => 'beam',
         },
         'spellbook of cause fear' => {
             price     => 300,
@@ -213,6 +269,8 @@ sub _list {
             time      => 6,
             ink       => 30,
             emergency => 0,
+            skill     => 'enchantment',
+            direction => 'nodir',
         },
         'spellbook of charm monster' => {
             price     => 300,
@@ -221,6 +279,8 @@ sub _list {
             ink       => 30,
             role      => 'Tou',
             emergency => 0,
+            skill     => 'enchantment',
+            direction => 'nodir',
         },
         'spellbook of protection' => {
             price     => 100,
@@ -228,6 +288,8 @@ sub _list {
             time      => 3,
             ink       => 10,
             emergency => 0,
+            skill     => 'clerical',
+            direction => 'nodir',
         },
         'spellbook of create monster' => {
             price     => 200,
@@ -235,6 +297,8 @@ sub _list {
             time      => 3,
             ink       => 20,
             emergency => 0,
+            skill     => 'clerical',
+            direction => 'nodir',
         },
         'spellbook of remove curse' => {
             price     => 300,
@@ -243,6 +307,8 @@ sub _list {
             ink       => 30,
             role      => 'Pri',
             emergency => 1,
+            skill     => 'clerical',
+            direction => 'nodir',
         },
         'spellbook of create familiar' => {
             price     => 600,
@@ -250,6 +316,8 @@ sub _list {
             time      => 42,
             ink       => 60,
             emergency => 0,
+            skill     => 'clerical',
+            direction => 'nodir',
         },
         'spellbook of turn undead' => {
             price     => 600,
@@ -258,6 +326,8 @@ sub _list {
             ink       => 60,
             role      => 'Kni',
             emergency => 0,
+            skill     => 'clerical',
+            direction => 'beam',
         },
         'spellbook of jumping' => {
             price     => 100,
@@ -265,6 +335,8 @@ sub _list {
             time      => 3,
             ink       => 10,
             emergency => 0,
+            skill     => 'escape',
+            direction => 'jump',
         },
         'spellbook of haste self' => {
             price     => 300,
@@ -273,6 +345,8 @@ sub _list {
             ink       => 30,
             role      => 'Bar',
             emergency => 0,
+            skill     => 'escape',
+            direction => 'nodir',
         },
         'spellbook of invisibility' => {
             price     => 400,
@@ -281,6 +355,8 @@ sub _list {
             ink       => 40,
             role      => 'Ran',
             emergency => 0,
+            skill     => 'escape',
+            direction => 'nodir',
         },
         'spellbook of levitation' => {
             price     => 400,
@@ -288,6 +364,8 @@ sub _list {
             time      => 12,
             ink       => 40,
             emergency => 0,
+            skill     => 'escape',
+            direction => 'nodir',
         },
         'spellbook of teleport away' => {
             price     => 600,
@@ -295,6 +373,8 @@ sub _list {
             time      => 36,
             ink       => 60,
             emergency => 0,
+            skill     => 'escape'
+            direction => 'beam',
         },
         'spellbook of knock' => {
             price     => 100,
@@ -302,6 +382,8 @@ sub _list {
             time      => 1,
             ink       => 10,
             emergency => 0,
+            skill     => 'matter',
+            direction => 'beam',
         },
         'spellbook of wizard lock' => {
             price     => 200,
@@ -309,6 +391,8 @@ sub _list {
             time      => 3,
             ink       => 20,
             emergency => 0,
+            skill     => 'matter',
+            direction => 'beam',
         },
         'spellbook of dig' => {
             price     => 500,
@@ -317,6 +401,8 @@ sub _list {
             ink       => 50,
             role      => 'Cav',
             emergency => 0,
+            skill     => 'matter',
+            direction => 'ray',
         },
         'spellbook of polymorph' => {
             price     => 600,
@@ -324,6 +410,8 @@ sub _list {
             time      => 48,
             ink       => 60,
             emergency => 0,
+            skill     => 'matter',
+            direction => 'beam',
         },
         'spellbook of cancellation' => {
             price     => 700,
@@ -331,6 +419,8 @@ sub _list {
             time      => 64,
             ink       => 70,
             emergency => 0,
+            skill     => 'matter',
+            direction => 'beam',
         },
     };
 
